@@ -556,3 +556,16 @@ def test_empty_element():
                 '''.encode('utf-8')
     messages = list(xml_extractor('filename', _options()))
     assert len(messages) == 1
+
+
+@pytest.mark.usefixtures('fake_source')
+def test_translation_context():
+    global source
+    source = u'''<html xmlns:i18n="http://xml.zope.org/namespaces/i18n"
+                      i18n:domain="lingua">
+                  <button i18n:context="form" i18n:translate="">Save</button>
+                </html>
+                '''.encode('utf-8')
+    messages = list(xml_extractor('filename', _options()))
+    assert messages[0].msgid == u'Save'
+    assert messages[0].msgctxt == u'form'
